# Part of Odoo. See LICENSE file for full copyright and licensing details.

from . import test_db_manager
from . import test_health
from . import test_image
from . import test_ir_model
from . import test_js
from . import test_router
from . import test_click_everywhere
from . import test_base_document_layout
from . import test_load_menus
from . import test_partner
from . import test_profiler
from . import test_session_info
from . import test_assets
from . import test_login
from . import test_web_search_read
from . import test_web_read_group
from . import test_domain
from . import test_translate
from . import test_web_redirect
from . import test_res_users
from . import test_webmanifest
from . import test_ir_qweb
from . import test_reports
